==> jasperreports-chart-themes-6.19.1-sources.jar: net/sf/jasperreports/chartthemes/simple/handlers/HorizontalAlignmentFieldHandler.java <==
/*
 * JasperReports - Free Java Reporting Library.
 * Copyright (C) 2001 - 2022 TIBCO Software Inc. All rights reserved.
 * http://www.jaspersoft.com
 *
 * Unless you have purchased a commercial license agreement from Jaspersoft,
 * the following license terms apply:
 *
 * This program is part of JasperReports.
 *
 * JasperReports is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * JasperReports is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
 */
package net.sf.jasperreports.chartthemes.simple.handlers;

import org.exolab.castor.mapping.GeneralizedFieldHandler;
import org.jfree.ui.HorizontalAlignment;


/**
 * @author Teodor Danciu (teodord@users.sourceforge.net)
 * @deprecated To be removed.
 */
public class HorizontalAlignmentFieldHandler extends GeneralizedFieldHandler
{
	/**
	 *
	 */
	public HorizontalAlignmentFieldHandler()
	{
		super();
	}
	
	@Override
	public Object convertUponGet(Object value)
	{
		return HorizontalAlignmentSerializer.convert((HorizontalAlignment)value);
	}

	@Override
	public Object convertUponSet(Object value)
	{
		if (value == null)
		{
			return null;
		}
		return 
			HorizontalAlignment.LEFT.toString().equals(value) 
			? HorizontalAlignment.LEFT 
			: HorizontalAlignment.CENTER.toString().equals(value)
			? HorizontalAlignment.CENTER
			: HorizontalAlignment.RIGHT.toString().equals(value)
			? HorizontalAlignment.RIGHT : null;
	}
	
	@Override
	public Class<?> getFieldType()
	{
		return HorizontalAlignment.class;
	}

	@Override
	public Object newInstance(Object parent) throws IllegalStateException
	{
		//-- Since it's marked as a string...just return null,
		//-- it's not needed.
		return null;
	}
}

==> jasperreports-chart-themes-6.20.0-sources.jar: net/sf/jasperreports/chartthemes/simple/handlers/HorizontalAlignmentFieldHandler.java <==
/*
 * JasperReports - Free Java Reporting Library.
 * Copyright (C) 2001 - 2022 TIBCO Software Inc. All rights reserved.
 * http://www.jaspersoft.com
 *
 * Unless you have purchased a commercial license agreement from Jaspersoft,
 * the following license terms apply:
 *
 * This program is part of JasperReports.
 *
 * JasperReports is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * JasperReports is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
 */
package net.sf.jasperreports.chartthemes.simple.handlers;

import org.exolab.castor.mapping.GeneralizedFieldHandler;
import org.jfree.ui.HorizontalAlignment;


/**
 * @author Teodor Danciu (teodord@users.sourceforge.net)
 * @deprecated To be removed.
 */
public class HorizontalAlignmentFieldHandler extends GeneralizedFieldHandler
{
	/**
	 *
	 */
	public HorizontalAlignmentFieldHandler()
	{
		super();
	}
	
	@Override
	public Object convertUponGet(Object value)
	{
		return HorizontalAlignmentSerializer.convert((HorizontalAlignment)value);
	}

	@Override
	public Object convertUponSet(Object value)
	{
		return HorizontalAlignmentDeserializer.convert((String) value);
	}
	
	@Override
	public Class<?> getFieldType()
	{
		return HorizontalAlignment.class;
	}

	@Override
	public Object newInstance(Object parent) throws IllegalStateException
	{
		//-- Since it's marked as a string...just return null,
		//-- it's not needed.
		return null;
	}
}
